# Global Utilities

> last modified 17 November, 2022 by Francisco

The `utilities-hki` repository contains the common utilities required by multiple other `humankind-datascience` repositories. Unlike the old `utilities` repo, this package contains no encrypted files, and credentials are now passed into the utility functions as input arguments.

## Development
To make changes to the package, follow the instructions at the accompanying [github repository](https://github.com/humankind-datascience/utilities-hki) 